@@ -3,7 +3,7 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-from typing import Dict, Optional, Sequence
+from typing import Dict, List, Optional, Sequence
 
 from blackboxopt.base import Objective
 
@@ -11,21 +11,26 @@ from blackboxopt.base import Objective
 def get_loss_vector(
     known_objectives: Sequence[Objective],
     reported_objectives: Dict[str, Optional[float]],
-) -> list:
+    none_replacement: float = float("NaN"),
+) -> List[float]:
     """Convert reported objectives into a vector of known objectives.
 
     Args:
-        known_objectives: [description]
-        reported_objectives: [description]
+        known_objectives: A sequence of objectives with names and directions
+            (whether greate is better). The order of the objectives dictates the order
+            of the returned loss values.
+        reported_objectives: A dictionary with the objective value for each of the known
+            objectives' names.
+        none_replacement: The value to use for missing objective values that are `None`
 
     Returns:
-        [description]
+        A list of loss values.
     """
     losses = []
     for objective in known_objectives:
         objective_value = reported_objectives[objective.name]
         if objective_value is None:
-            losses.append(float("NaN"))
+            losses.append(none_replacement)
         elif objective.greater_is_better:
             losses.append(-1.0 * objective_value)
         else:
